@@ -31,7 +31,7 @@ max_EI <-function(model, lower, upper, parinit=NULL, control=NULL) {
            	hard.generation.limit=TRUE, starting.values=parinit, MemoryMatrix=TRUE, 
            	Domains=domaine, default.domains=10, solution.tolerance=0.01,
           	gr=gr, boundary.enforcement=2, lexical=FALSE, gradient.check=FALSE, BFGS=TRUE,
-          	data.type.int=FALSE, hessian=TRUE, unif.seed=812821, int.seed=53058,
+          	data.type.int=FALSE, hessian=TRUE, unif.seed=floor(runif(1,max=10000)), int.seed=floor(runif(1,max=10000)),
           	print.level=0, share.type=0, instance.number=0,
           	output.path="stdout", output.append=FALSE, project.path=NULL,
          	P1=50, P2=50, P3=50, P4=50, P5=50, P6=50, P7=50, P8=50, P9=0,
